package net.wanji.opt.controller.induce;


import freemarker.template.TemplateException;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.entity.InduceTemplate;
import net.wanji.opt.dto.induce.MessageParam;
import net.wanji.opt.service.induce.InduceSendService;
import net.wanji.opt.service.induce.InduceTemplateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;
import java.nio.charset.StandardCharsets;

@Api(value = "InduceSendController", description = "诱导屏-下发消息接口（对接易华录）")
@RestController
@RequestMapping("/induce")
@Slf4j
public class InduceSendController {

    @Autowired
    private InduceSendService induceSendService;

    @Autowired
    private InduceTemplateService induceTemplateService;


    @PostMapping("/send")
    public JsonViewObject send(@RequestBody MessageParam param) {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            induceSendService.send(param);
            return jsonView.success();
        } catch (Exception e) {
            log.info(e.getMessage());
            return jsonView.fail("发送失败");
        }
    }

    /**
     * 获取ftp图片
     */
    @GetMapping(value = "/file")
    public ResponseEntity<byte[]> ftpFile(@RequestParam("fileId") Long fileId) {
        // 根据 fileId 获取文件名
        InduceTemplate pictureFile = this.induceTemplateService.getById(fileId);
        if (pictureFile == null) {
            return ResponseEntity.status(HttpStatus.OK)
                    .body("无效的文件ID".getBytes(StandardCharsets.UTF_8));
        }
        try {
            // 获取ftp服务器图片
            byte[] imageBytes = this.induceSendService.downloadImage(pictureFile.getFileName());
            if (imageBytes != null && imageBytes.length > 0) {
                // 设置响应头
                HttpHeaders headers = new HttpHeaders();
                headers.set("Content-Type", "image/jpeg"); // 图片类型
                headers.set("Content-Length", String.valueOf(imageBytes.length)); // 设置内容长度
                headers.set("Content-Disposition", "inline; filename=\"" + pictureFile.getFileName() + "\""); // 设置文件名
                // 返回响应
                return new ResponseEntity<>(imageBytes, headers, HttpStatus.OK);
            } else {
                return ResponseEntity.status(HttpStatus.OK)
                        .body("未查询到对应文件".getBytes(StandardCharsets.UTF_8));
            }
        } catch (IOException e) {
            log.error("ftp文件下载失败: ", e.getMessage());
            return ResponseEntity.status(HttpStatus.OK)
                    .body("程序查询错误请联系管理员".getBytes(StandardCharsets.UTF_8));
        }
    }

}
